@@ -57,7 +57,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Run Perl code written in your plugin's F<dist.ini> section
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
@@ -111,7 +111,7 @@ has code => (
 #pod = C<$dist>
 #pod Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
 #pod = C<$arg>
-#pod The same as C<$args[ 0 ]>.
+#pod The same as C<$_[ 0 ]>.
 #pod = C<@_>
 #pod C<hook> arguments, self-reference is already shifted!
 #pod
@@ -171,7 +171,7 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
 #pod
 #pod     my @code = $self->prologue;
 #pod
-#pod The methods returns prologue code.
+#pod The method returns prologue code.
 #pod
 #pod Prologue code is extracted from C<Dist::Zilla> plugin named C<prologue>.
 #pod
@@ -241,7 +241,7 @@ Dist::Zilla::Role::Hooker - Run Perl code written in your plugin's F<dist.ini> s
 
 =head1 VERSION
 
-Version 0.002, released on 2015-07-23 22:08 UTC.
+Version 0.003, released on 2015-07-25 21:49 UTC.
 
 =head1 WHAT?
 
@@ -308,7 +308,7 @@ Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
 
 =item C<$arg>
 
-The same as C<$args[ 0 ]>.
+The same as C<$_[ 0 ]>.
 
 =item C<@_>
 
@@ -322,7 +322,7 @@ If code dies, the method logs error message and aborts C<Dist::Zilla>.
 
     my @code = $self->prologue;
 
-The methods returns prologue code.
+The method returns prologue code.
 
 Prologue code is extracted from C<Dist::Zilla> plugin named C<prologue>.
 
